@@ -5,21 +5,28 @@ from unittest import TestCase
 from pptx import Presentation
 from pptx.presentation import Presentation as PresentationType
 
-from PPTT.utils import find_shape, find_shape_by_slide_layout
+from ...PPTT.utils import find_shape, find_shape_by_slide_layout
 
 
 class PPTTTestCase(TestCase):
+    deubg = False  # if true you can get target.ppt easy and doesn't delete after test end
     master_slide = ''
     temp_dir = None
     target_slide = ''
 
     def setUp(self):
-        self.temp_dir = tempfile.TemporaryDirectory()
-        self.target_slide = os.path.join(self.temp_dir.name, 'target.pptx')
+        temp_dir_name = self.temp_dir
+        if not all([self.deubg, self.temp_dir]):
+            self.temp_dir = tempfile.TemporaryDirectory()
+            temp_dir_name = self.temp_dir.name
+
+        self.target_slide = os.path.join(temp_dir_name, 'target.pptx')
 
     def tearDown(self):
-        self.temp_dir.cleanup()
-        self.temp_dir = None
+        if not all([self.deubg, self.temp_dir]):
+            self.temp_dir.cleanup()
+        if all([self.deubg, self.temp_dir]):
+            self.temp_dir = None
 
     def get_master_ppt(self) -> PresentationType:
         return Presentation(self.master_slide)
@@ -34,17 +41,3 @@ class PPTTTestCase(TestCase):
     @staticmethod
     def find_shape(slide, name):
         return find_shape(slide, name)
-
-
-class DebugPPTTestCase(PPTTTestCase):
-    """
-    help debuging pptx when develop testcase
-    """
-    temp_dir = None
-    target_slide = ''
-
-    def setUp(self):
-        self.target_slide = os.path.join(self.temp_dir, 'target.pptx')
-
-    def tearDown(self):
-        pass
